jj_save_bed: write Granges or region string vector to bed file

View source: R/jj_load_save_bed.R

jj_save_bedR Documentation

write Granges or region string vector to bed file

Description

estimate densities to include density area in tsne/umap

Usage

jj_save_bed(regions, file_name)

Arguments

regions

regions to save to bed file, either as GRanges or as strings in the format 'chr1-1-99'

file_name

file name to save to or load from

return_granges

if TRUE, return a GRanges object instead of a tibble when loading data

Examples

jj_save_bed(c('chr1-234-3488', 'chrX-300-1500'), 'test.bed')
jj_load_bed('test.bed', return_granges = TRUE)

mathosi/jj documentation built on Feb. 25, 2024, 2:29 p.m.