View source: R/jj_load_save_bed.R
| jj_save_bed | R Documentation |
estimate densities to include density area in tsne/umap
jj_save_bed(regions, file_name)
regions |
regions to save to bed file, either as GRanges or as strings in the format 'chr1-1-99' |
file_name |
file name to save to or load from |
return_granges |
if TRUE, return a GRanges object instead of a tibble when loading data |
jj_save_bed(c('chr1-234-3488', 'chrX-300-1500'), 'test.bed')
jj_load_bed('test.bed', return_granges = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.